==> open-xchange-usm_6.18.0.0.orig.tar.gz: open-xchange-usm-6.18.0.0/com.openexchange.usm.json/src/com/openexchange/usm/json/push/PushNotificationService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.json.push;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import com.openexchange.usm.connector.commands.PushNotificationType;
import com.openexchange.usm.json.USMSessionID;

public class PushNotificationService {

	private static PushNotificationService _instance;

	private boolean isRunning;

	private Map<USMSessionID, PushNotificationType> _map;

	public synchronized static PushNotificationService getInstance() {
		if (_instance == null) {
			_instance = new PushNotificationService();
		}
		return _instance;
	}

	public void setValue(USMSessionID key, PushNotificationType value) {
		_map.put(key, value);
	}

	public PushNotificationType getValue(USMSessionID key) {
		return _map.get(key);
	}

	public boolean containKey(USMSessionID key) {
		return _map.containsKey(key);
	}

	public PushNotificationType removeValue(USMSessionID key) {
		return _map.remove(key);
	}

	public void startup() {
		if (isRunning)
			return;
		_map = new ConcurrentHashMap<USMSessionID, PushNotificationType>();
		isRunning = true;
	}

	public void shutdown() {
		if (!isRunning)
			return;
		_map.clear();
		isRunning = false;
	}

	public boolean isRun() {
		return isRunning;
	}
}

==> open-xchange-usm_6.20.8.0.orig.tar.gz: open-xchange-usm-6.20.8.0/com.openexchange.usm.json/src/com/openexchange/usm/json/push/PushNotificationService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.json.push;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import com.openexchange.usm.connector.commands.PushNotificationType;
import com.openexchange.usm.json.USMSessionID;

public class PushNotificationService {

	private static PushNotificationService _instance;

	private boolean isRunning;

	private Map<USMSessionID, PushNotificationType> _map;

	public static synchronized PushNotificationService getInstance() {
		if (_instance == null) {
			_instance = new PushNotificationService();
		}
		return _instance;
	}

	public void setValue(USMSessionID key, PushNotificationType value) {
		_map.put(key, value);
	}

	public PushNotificationType getValue(USMSessionID key) {
		return _map.get(key);
	}

	public boolean containKey(USMSessionID key) {
		return _map.containsKey(key);
	}

	public PushNotificationType removeValue(USMSessionID key) {
		return _map.remove(key);
	}

	public void startup() {
		if (isRunning)
			return;
		_map = new ConcurrentHashMap<USMSessionID, PushNotificationType>();
		isRunning = true;
	}

	public void shutdown() {
		if (!isRunning)
			return;
		_map.clear();
		isRunning = false;
	}

	public boolean isRun() {
		return isRunning;
	}
}
